@@ -32,14 +32,15 @@ test_hloc_impl(sirius::Simulation_context& ctx__, int num_bands__, int use_gpu__
 
     sirius::Local_operator<T> hloc(ctx__, fft, gvec_fft);
 
-    wf::Wave_functions<T> phi(gvec, wf::num_mag_dims(0), wf::num_bands(4 * num_bands__), memory_t::host);
+    wf::Wave_functions<T> phi(gvec, wf::num_mag_dims(0), wf::num_bands(4 * num_bands__), memory_t::host_pinned);
+    #pragma omp patallel for
     for (int i = 0; i < 4 * num_bands__; i++) {
         for (int j = 0; j < phi.ld(); j++) {
             phi.pw_coeffs(j, wf::spin_index(0), wf::band_index(i)) = random<std::complex<T>>();
         }
         phi.pw_coeffs(0, wf::spin_index(0), wf::band_index(i)) = 1.0;
     }
-    wf::Wave_functions<T> hphi(gvec, wf::num_mag_dims(0), wf::num_bands(4 * num_bands__), memory_t::host);
+    wf::Wave_functions<T> hphi(gvec, wf::num_mag_dims(0), wf::num_bands(4 * num_bands__), memory_t::host_pinned);
 
     {
         auto mem_phi         = (use_gpu__) ? memory_t::device : memory_t::host;
@@ -59,6 +60,7 @@ test_hloc_impl(sirius::Simulation_context& ctx__, int num_bands__, int use_gpu__
     }
 
     double diff{0};
+    #pragma omp parallel for reduction(+:diff)
     for (int i = 0; i < 4 * num_bands__; i++) {
         for (int j = 0; j < phi.ld(); j++) {
             int ig  = gvec->offset() + j;
@@ -69,6 +71,7 @@ test_hloc_impl(sirius::Simulation_context& ctx__, int num_bands__, int use_gpu__
                              2);
         }
     }
+
     if (diff != diff) {
         RTE_THROW("NaN");
     }
